================
ACDH XML PyUtils
================

.. image:: https://github.com/acdh-oeaw/acdh_xml_pyutils/workflows/Build%20acdh_xml_pyutils%20Package/badge.svg
        :target: https://github.com/acdh-oeaw/acdh_xml_pyutils/workflows/Build%20acdh_xml_pyutils%20Package/badge.svg
        :alt: Github Workflow Build ACDH XML PyUtils Status

.. image:: https://github.com/acdh-oeaw/acdh_xml_pyutils/workflows/Run%20acdh_xml_pyutils%20Tox%20Test%20Suite/badge.svg
        :target: https://github.com/acdh-oeaw/acdh_xml_pyutils/workflows/Run%20acdh_xml_pyutils%20Tox%20Test%20Suite/badge.svg
        :alt: Github Workflow Tests Status

.. image:: https://img.shields.io/pypi/v/ACDH XML PyUtils.svg
        :target: https://pypi.python.org/pypi/ACDH XML PyUtils
        :alt: PyPI Status


.. image:: https://readthedocs.org/projects/ACDH XML PyUtils/badge/?version=latest
        :target: https://ACDH XML PyUtils.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Utility functions to work with XML


* Free software: MIT
* Documentation: https://acdh-xml-pyutils.readthedocs.io.


Features
--------

* parse XML from files, strings or URLS
* print/save parsed files

see `tests/test_xml.py` for usage examples

Credits
-------

This package was created with cookietemple_ using Cookiecutter_.

.. _cookietemple: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
